0.3.7
-----

* Update django head version

0.3.6
-----

* Update django head version

0.3.5
-----

* Add CHANGELOG.rst into manifest

0.3.4
-----
* Remove deprecation warning

0.3.3
-----

* Moved the **ct** shortcut into **utils** module

0.3.2
-----

* Added CHANGELOG :)
* Added Python 3.4x support;
* Dropped Python 3.2x support;
* Improved code styling with pep8;
* Wheel available;
* Coverage support;
* Updated Django head version;
* Fix 0.3.1 install bug (import six from django).


